package com.bonus.zlpt.equip.service.impl;

import java.util.List;

import com.bonus.zlpt.equip.api.domain.UserCollect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.zlpt.equip.mapper.UserCollectMapper;
import com.bonus.zlpt.equip.service.IUserCollectService;

/**
 * 我的收藏
Service业务层处理
 * 
 * @author xsheng
 * @date 2023-12-02
 */
@Service
public class UserCollectServiceImpl implements IUserCollectService 
{
    @Autowired
    private UserCollectMapper userCollectMapper;

    /**
     * 查询我的收藏

     * 
     * @param id 我的收藏
主键
     * @return 我的收藏

     */
    @Override
    public UserCollect selectUserCollectById(Long id)
    {
        return userCollectMapper.selectUserCollectById(id);
    }

    /**
     * 查询我的收藏
列表
     * 
     * @param userCollect 我的收藏

     * @return 我的收藏

     */
    @Override
    public List<UserCollect> selectUserCollectList(UserCollect userCollect)
    {
        return userCollectMapper.selectUserCollectList(userCollect);
    }

    /**
     * 新增我的收藏

     * 
     * @param userCollect 我的收藏

     * @return 结果
     */
    @Override
    public int insertUserCollect(UserCollect userCollect)
    {
        return userCollectMapper.insertUserCollect(userCollect);
    }

    /**
     * 修改我的收藏

     * 
     * @param userCollect 我的收藏

     * @return 结果
     */
    @Override
    public int updateUserCollect(UserCollect userCollect)
    {
        return userCollectMapper.updateUserCollect(userCollect);
    }

    /**
     * 批量删除我的收藏

     * 
     * @param ids 需要删除的我的收藏
主键
     * @return 结果
     */
    @Override
    public int deleteUserCollectByIds(Long[] ids)
    {
        return userCollectMapper.deleteUserCollectByIds(ids);
    }

    /**
     * 删除我的收藏
信息
     * 
     * @param id 我的收藏
主键
     * @return 结果
     */
    @Override
    public int deleteUserCollectByMaId(Long maId)
    {
        return userCollectMapper.deleteUserCollectByMaId(maId);
    }
}
